# Chart 1.x to 2.x migration guide

The `datadog` chart has been refactored to regroup the `values.yaml` parameters in a more logical way.
Migrating from chart v1 to chart v2 hence requires that you restructure the `values.yaml` file.
For all the parameters in the existing `values.yaml` file that applied to chart v1, you’ll
find the parameters to which they correspond to in v2 in the following table.
Parameters that are not listed in the table below haven’t been touched and are at the same
location in v1 and v2.

| Old parameter                           | New location                                                                | comment                                                                                                                                                 |
| -------------                           | ------------                                                                | -------                                                                                                                                                 |
| `image.repository`                      | `agents.image.repository` and `clusterCheckRunner.image.repository`         |                                                                                                                                                         |
| `image.tag`                             | `agents.image.tag` and `clusterCheckRunner.image.tag`                |                                                                                                                                                         |
| `image.pullPolicy`                      | `agents.image.pullPolicy` and `clusterCheckRunner.image.pullPolicy`         |                                                                                                                                                         |
| `image.pullSecrets`                     | `agents.image.pullSecrets` and `clusterCheckRunner.image.pullSecrets`         |                                                                                                                                                         |
| `datadog.name`                          | ∅                                                                           | The name of the container inside the Agent and Cluster Agent pod isn’t configurable anymore                                                             |
| `datadog.useCriSocketVolume`            | ∅                                                                           | If `datadog.criSocketPath` is defined, the socket will be mounted inside the container without needing to set `datadog.useCriSocketVolume` in addition. |
| `datadog.containerLogsPath`             | ∅                                                                           | Not needed anymore because the chart automatically detects if the CRI is `docker` based on `criSocketPath` and mounts the path accordingly              |
| `datadog.apmEnabled`                    | `datadog.apm.portEnabled` `datadog.apm.socketEnabled`                       |                                                                                                                                                         |
| `datadog.processAgentEnabled`           | `datadog.processAgent.enabled` and `datadog.processAgent.processCollection:true`                                       |                                                                                                              |
| `datadog.volumes`                       | `agents.volumes`                                                             |                                                                                                                                                         |
| `datadog.volumeMounts`                  | `agents.volumeMounts`                                                        |                                                                                                                                                         |
| `datadog.livenessProbe`                 | `agents.containers.agent.livenessProbe`                                     |                                                                                                                                                         |
| `datadog.resources`                     | `agents.containers.agent.resources`                                         |                                                                                                                                                         |
| `datadog.dogstatsdOriginDetection`      | `datadog.dogstatsd.originDetection`                                                         |                                                                                                                                                         |
| `datadog.useDogStatsDSocketVolume`      | `datadog.dogstatsd.useSocketVolume`                                                         |                                                                                                                                                         |
| `systemProbe.enabled`                   | `datadog.securityAgent.runtime.enabled`, `datadog.networkMonitoring.enabled`, `datadog.systemProbe.enableTCPQueueLength`, `datadog.systemProbe.enableOOMKill` | |
| `systemProbe.debugPort`                 | `datadog.systemProbe.debugPort`                                             |                                                                                                                                                         |
| `systemProbe.enableConntrack`           | `datadog.systemProbe.enableConntrack`                                       |                                                                                                                                                         |
| `systemProbe.seccomp`                   | `datadog.systemProbe.seccomp`                                               |                                                                                                                                                         |
| `systemProbe.seccompRoot`               | `datadog.systemProbe.seccompRoot`                                           |                                                                                                                                                         |
| `systemProbe.bpfDebug`                  | `datadog.systemProbe.bpfDebug`                                              |                                                                                                                                                         |
| `systemProbe.apparmor`                  | `datadog.systemProbe.apparmor`                                              |                                                                                                                                                         |
| `clusterAgent.containerName`            | ∅                                                                           | The name of the container inside the Cluster Agent pod isn’t configurable anymore                                                                       |
| `clusterAgent.clusterChecks.enabled`    | `datadog.clusterChecks.enabled`                                             |                                                                                                                                                         |
| `rbac.create`                           | `agents.rbac.create` and `clusterAgent.rbac.create`                         |                                                                                                                                                         |
| `rbac.serviceAccountName`               | `agents.rbac.serviceAccountName` and `clusterAgent.rabc.serviceAccountName` |                                                                                                                                                         |
| `tolerations`                           | `agents.tolerations`                                                         |                                                                                                                                                         |
| `kubeStateMetrics.enabled`              | `datadog.kubeStateMetricsEnabled`                                           |                                                                                                                                                         |
| `daemonset.enabled`                     | `agents.enabled`                                                            |                                                                                                                                                         |
| `daemonset.containers.agent.*`          | `agents.containers.agent.*`                                                 |                                                                                                                                                         |
| `daemonset.containers.processAgent.*`   | `agents.containers.processAgent.*`                                          |                                                                                                                                                         |
| `daemonset.containers.traceAgent.*`     | `agents.containers.traceAgent.*`                                            |                                                                                                                                                         |
| `daemonset.containers.systemProbe.*`    | `agents.containers.systemProbe.*`                                           |                                                                                                                                                         |
| `daemonset.useHostNetwork`              | `agents.useHostNetwork`                                                     |                                                                                                                                                         |
| `daemonset.dogstatsdPort`                 | `datadog.dogstatsd.port`                                                        |                                                                                                                                                         |
| `daemonset.useHostPort`                 | `datadog.dogstatsd.useHostPort`                                                        |                                                                                                                                                         |
| `daemonset.useHostPID`                  | `datadog.dogstatsd.useHostPID`                                                         |                                                                                                                                                         |
| `daemonset.nonLocalTraffic`              | `datadog.dogstatsd.nonLocalTraffic`                                                     |                                                                                                                                                         |
| `daemonset.podAnnotations`              | `agents.podAnnotations`                                                     |                                                                                                                                                         |
| `daemonset.tolerations`                 | `agents.tolerations`                                                        |                                                                                                                                                         |
| `daemonset.nodeSelector`                | `agents.nodeSelector`                                                       |                                                                                                                                                         |
| `daemonset.affinity`                    | `agents.affinity`                                                           |                                                                                                                                                         |
| `daemonset.updateStrategy`              | `agents.updateStrategy`                                                     |                                                                                                                                                         |
| `daemonset.priorityClassName`           | `agents.priorityClassName`                                                  |                                                                                                                                                         |
| `daemonset.podLabels`                   | `agents.podLabels`                                                          |                                                                                                                                                         |
| `daemonset.useConfigMap`                | `agents.useConfigMap`                                                       |                                                                                                                                                         |
| `daemonset.customAgentConfig.*`         | `agents.customAgentConfig.*`                                                |                                                                                                                                                         |
| `daemonset.useDedicatedContainers`      | ∅                                                                           |                                                                                                                                                         |
| `deployment.*`                          | ∅                                                                           |                                                                                                                                                         |
| `clusterchecksDeployment.enabled`       | `clusterChecksRunner.enabled`                                               |                                                                                                                                                         |
| `clusterchecksDeployment.rbac.*`        | `clusterChecksRunner.rbac.*`                                                |                                                                                                                                                         |
| `clusterchecksDeployment.replicas`      | `clusterChecksRunner.replicas`                                              |                                                                                                                                                         |
| `clusterchecksDeployment.resources.*`   | `clusterChecksRunner.resources.*`                                           |                                                                                                                                                         |
| `clusterchecksDeployment.affinity`      | `clusterChecksRunner.affinity`                                              |                                                                                                                                                         |
| `clusterchecksDeployment.strategy`      | `clusterChecksRunner.strategy`                                              |                                                                                                                                                         |
| `clusterchecksDeployment.nodeSelector`  | `clusterChecksRunner.nodeSelector`                                          |                                                                                                                                                         |
| `clusterchecksDeployment.tolerations`   | `clusterChecksRunner.tolerations`                                           |                                                                                                                                                         |
| `clusterchecksDeployment.livenessProbe` | `clusterChecksRunner.livenessProbe`                                         |                                                                                                                                                         |
| `clusterchecksDeployment.env`           | `clusterChecksRunner.env`                                                   |                                                                                                                                                         |
| `logsEnabled`                    | `datadog.logs.enabled`                                                       |                                                                                                                                                         |
| `logsConfigContainerCollectAll`                    | `datadog.logs.containerCollectAll`                                                       |                                                                                                                                                         |
